import {IsolatedTemplateStateGenerator} from "./IsolatedTemplateStateGenerator";
import {ProductGenerationData} from "./ProductGenerationData";
import {ProductGeneratorResult} from "./ProductGeneratorResult";
import {ProductState} from "../states/ProductState";
import {SimpleState} from "../states/SimpleState";
import {State} from "../states/State";
import {ScriptAccountCondition} from "../conditions/ScriptAccountCondition";

export class IsolatedSymmetricTemplateStateGenerator extends IsolatedTemplateStateGenerator{


  protected generateBinaryIsolatedProductStates(leftSystemData: ProductGenerationData, rightSystemData: ProductGenerationData): ProductGeneratorResult {

    const generatedProductStates: ProductState[] = []
    leftSystemData.states.forEach(leftState => {
      if(leftState.outgoingTransitions.length == 0 && leftState.incomingTransitions.length == 0) {
        rightSystemData.states.forEach(rightState => {
          if(leftState.equals(rightState)) {
            if(rightState.outgoingTransitions.length == 0 && rightState.incomingTransitions.length == 0) {
              const leftConditions = this.getStateConditions(leftState, true);
              const rightConditions = this.getStateConditions(rightState, true);

              if(!this.contradictCombinedConditions(leftConditions, rightConditions)) {
                this.generateBinaryProductState(leftState, rightState, generatedProductStates);
              }
            }
          }

          if(leftState.equals(rightState) && rightState.outgoingTransitions.length == 0 && rightState.incomingTransitions.length == 0) {
            const leftConditions = this.getStateConditions(leftState, true);
            const rightConditions = this.getStateConditions(rightState, true);

            if(!this.contradictCombinedConditions(leftConditions, rightConditions)) {
              const generatedState = this.generateBinaryProductState(leftState, rightState, generatedProductStates);
            }
          }
        })
      }
    })
    return new ProductGeneratorResult(generatedProductStates, []);
  }
}
